@@ -2,7 +2,7 @@ from typing import List
 
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
-from checkov.common.util.secrets import string_has_secrets, AWS
+from checkov.common.util.secrets import string_has_secrets
 
 class EC2Credentials(BaseResourceCheck):
     def __init__(self):
