@@ -5,7 +5,7 @@ from checkov.cloudformation.checks.resource.base_resource_check import BaseResou
 
 class EKSNodeGroupRemoteAccess(BaseResourceCheck):
     def __init__(self):
-        name = "Ensure Amazon EKS Node group has implicit SSH access from 0.0.0.0/0"
+        name = "Ensure AWS EKS node group does not have implicit SSH access from 0.0.0.0/0"
         id = "CKV_AWS_100"
         supported_resources = ['AWS::EKS::Nodegroup']
         categories = [CheckCategories.KUBERNETES]
