@@ -11,4 +11,4 @@ class ExistsAttributeSolver(BaseAttributeSolver):
         super().__init__(resource_types=resource_types, attribute=attribute, value=value)
 
     def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
-        return vertex.get(attribute) is not None
+        return vertex.get(attribute) is not None  # type:ignore[arg-type]  # due to attribute can be None
