@@ -1,4 +1,6 @@
-from typing import List, Any, Callable
+from __future__ import annotations
+
+from typing import Any, Callable
 
 from checkov.common.graph.checks_infra.enums import Operators
 from checkov.common.checks_infra.solvers.filter_solvers.base_filter_solver import BaseFilterSolver
@@ -7,14 +9,14 @@ from checkov.common.checks_infra.solvers.filter_solvers.base_filter_solver impor
 class WithinFilterSolver(BaseFilterSolver):
     operator = Operators.WITHIN
 
-    def __init__(self, resource_types: List[str], attribute: str, value: Any) -> None:
+    def __init__(self, resource_types: list[str], attribute: str, value: Any) -> None:
         super().__init__(resource_types=resource_types, attribute=attribute, value=value)
 
     def get_operation(self, *args: Any, **kwargs: Any) -> bool:
         return self._get_operation()(*args)
 
     def _get_operation(self, *args: Any, **kwargs: Any) -> Callable[..., bool]:
-        def op(check):
+        def op(check: dict[str, Any]) -> bool:
             val = check.get(self.attribute)
-            return val and (val in self.value)
+            return bool(val) and (val in self.value)
         return op
