@@ -1,11 +1,16 @@
+from __future__ import annotations
+
 import itertools
-from typing import Optional, Tuple, List, Dict, Any
+from typing import Optional, Tuple, List, Dict, Any, TYPE_CHECKING
 
 from networkx import DiGraph
 
 from checkov.common.graph.checks_infra.enums import SolverType
 from checkov.common.graph.checks_infra.solvers.base_solver import BaseSolver
 
+if TYPE_CHECKING:
+    from checkov.common.bridgecrew.severities import Severity
+
 
 class BaseGraphCheck:
     def __init__(self) -> None:
@@ -22,11 +27,18 @@ class BaseGraphCheck:
         self.type: Optional[SolverType] = None
         self.solver: Optional[BaseSolver] = None
         self.guideline: Optional[str] = None
+        self.benchmarks: Dict[str, List[str]] = {}
+        self.severity: Optional[Severity] = None
+        self.bc_category: Optional[str] = None
+        self.frameworks: list[str] = []
 
     def set_solver(self, solver: BaseSolver) -> None:
         self.solver = solver
 
     def run(self, graph_connector: DiGraph) -> Tuple[List[Dict[str, Any]], List[Dict[str, Any]]]:
+        if not self.solver:
+            raise AttributeError("solver attribute was not set")
+
         return self.solver.run(graph_connector=graph_connector)
 
     def get_output_id(self, use_bc_ids: bool) -> str:
