@@ -24,6 +24,7 @@ class SolverType(str, Enum):
 class Operators:
     ANY = 'any'
     EXISTS = 'exists'
+    ONE_EXISTS = 'one_exists'
     NOT_EXISTS = 'not_exists'
     CONTAINS = 'contains'
     NOT_CONTAINS = 'not_contains'
@@ -39,6 +40,10 @@ class Operators:
     LESS_THAN_OR_EQUAL = 'less_than_or_equal'
     STARTING_WITH = 'starting_with'
     NOT_STARTING_WITH = 'not_starting_with'
+    SUBSET = 'subset'
+    NOT_SUBSET = 'not_subset'
     WITHIN = 'within'
     AND = 'and'
     OR = 'or'
+    JSONPATH_EQUALS = 'jsonpath_equals'
+    JSONPATH_EXISTS = 'jsonpath_exists'
