@@ -1,10 +1,12 @@
+from __future__ import annotations
+
 import logging
 import os
 from abc import ABC, abstractmethod
 from typing import TYPE_CHECKING, List, Dict, Any, Iterable
 
 from checkov.common.graph.graph_builder import Edge
-from checkov.common.graph.graph_builder.utils import calculate_hash, run_function_multithreaded
+from checkov.common.graph.graph_builder.utils import run_function_multithreaded
 
 if TYPE_CHECKING:
     from checkov.common.graph.graph_builder.local_graph import LocalGraph
@@ -36,7 +38,7 @@ class VariableRenderer(ABC):
         edges_to_render = self.local_graph.get_in_edges(end_vertices_indexes)
         end_vertices_indexes = set()
         loops = 0
-        evaluated_edges_cache = [[], []]
+        evaluated_edges_cache: list[list[Edge]] = [[], []]
         duplicates_count = 0
         while edges_to_render:
             evaluated_edges_two_iter_ago = evaluated_edges_cache[-2]
