@@ -1,10 +1,12 @@
+from __future__ import annotations
+
+from typing import Any
+
 from checkov.common.output.record import Record
 
 
 class GraphRecord(Record):
-    breadcrumbs = {}
-
-    def __init__(self, record, breadcrumbs):
+    def __init__(self, record: Record, breadcrumbs: dict[str, dict[str, Any]]):
         super().__init__(record.check_id, record.check_name, record.check_result, record.code_block, record.file_path,
                          record.file_line_range, record.resource, record.evaluations, record.check_class,
                          record.file_abs_path, record.entity_tags, record.caller_file_path,
