@@ -1,17 +1,22 @@
+from __future__ import annotations
+
 import itertools
 import os
 import re
 from abc import ABC, abstractmethod
-from typing import List, Dict, Optional, Any, Union
+from typing import List, Dict, Optional, Any, Union, TYPE_CHECKING, Iterable
 
 from checkov.common.graph.checks_infra.base_check import BaseGraphCheck
 from checkov.common.output.report import Report
 from checkov.runner_filter import RunnerFilter
 
-IGNORED_DIRECTORIES_ENV = os.getenv("CKV_IGNORED_DIRECTORIES", "node_modules,.terraform,.serverless")
+if TYPE_CHECKING:
+    from checkov.common.checks_infra.registry import Registry
+    from checkov.common.graph.checks_infra.registry import BaseRegistry
+    from checkov.common.graph.graph_manager import GraphManager
 
 
-def strtobool(val):
+def strtobool(val: str) -> int:
     """Convert a string representation of truth to true (1) or false (0).
 
     True values are 'y', 'yes', 't', 'true', 'on', and '1'; false values
@@ -27,6 +32,8 @@ def strtobool(val):
         raise ValueError("invalid boolean value %r for environment variable CKV_IGNORE_HIDDEN_DIRECTORIES" % (val,))
 
 
+CHECKOV_CREATE_GRAPH = strtobool(os.getenv("CHECKOV_CREATE_GRAPH", "True"))
+IGNORED_DIRECTORIES_ENV = os.getenv("CKV_IGNORED_DIRECTORIES", "node_modules,.terraform,.serverless")
 IGNORE_HIDDEN_DIRECTORY_ENV = strtobool(os.getenv("CKV_IGNORE_HIDDEN_DIRECTORIES", "True"))
 
 ignored_directories = IGNORED_DIRECTORIES_ENV.split(",")
@@ -35,29 +42,49 @@ ignored_directories = IGNORED_DIRECTORIES_ENV.split(",")
 class BaseRunner(ABC):
     check_type = ""
     definitions = None
-    context = None
+    context: dict[str, dict[str, Any]] | None = None
     breadcrumbs = None
-    external_registries = None
-    graph_manager = None
-    graph_registry = None
+    external_registries: list[BaseRegistry] | None = None
+    graph_manager: GraphManager | None = None
+    graph_registry: Registry | None = None
+
+    def __init__(self, file_extensions: Optional[Iterable[str]] = [], file_names: Optional[Iterable[str]] = []):
+        self.file_extensions = file_extensions
+        self.file_names = file_names
 
     @abstractmethod
     def run(
             self,
-            root_folder: str,
-            external_checks_dir: Optional[List[str]] = None,
-            files: Optional[List[str]] = None,
+            root_folder: str | None,
+            external_checks_dir: list[str] | None = None,
+            files: list[str] | None = None,
             runner_filter: RunnerFilter = RunnerFilter(),
             collect_skip_comments: bool = True,
     ) -> Report:
         pass
 
+    def should_scan_file(self, filename: str) -> bool:
+        # runners that are always applicable can do nothing and be included
+        if not self.file_extensions and not self.file_names:
+            return True
+
+        basename = os.path.basename(filename)
+        if basename and self.file_names and basename in self.file_names:
+            return True
+
+        extension = os.path.splitext(filename)[1]
+        if extension and self.file_extensions and extension in self.file_extensions:
+            return True
+
+        return False
+
     def set_external_data(
             self,
             definitions: Optional[Dict[str, Dict[str, Any]]],
             context: Optional[Dict[str, Dict[str, Any]]],
-            breadcrumbs: Optional[Dict],
-    ):
+            breadcrumbs: Optional[Dict[str, Dict[str, Any]]],
+            **kwargs
+    ) -> None:
         self.definitions = definitions
         self.context = context
         self.breadcrumbs = breadcrumbs
@@ -77,7 +104,7 @@ class BaseRunner(ABC):
         return checks_results
 
 
-def filter_ignored_paths(root_dir: str, names: List[Union[str, os.DirEntry]], excluded_paths: Optional[List[str]]) -> None:
+def filter_ignored_paths(root_dir: str, names: List[Union[str, os.DirEntry]], excluded_paths: Optional[List[str]], included_paths: Optional[List[str]] = None) -> None:
     # we need to handle legacy logic, where directories to skip could be specified using the env var (default value above)
     # or a directory starting with '.'; these look only at directory basenames, not relative paths.
     #
@@ -97,11 +124,12 @@ def filter_ignored_paths(root_dir: str, names: List[Union[str, os.DirEntry]], ex
 
     # first handle the legacy logic - this will also remove files starting with '.' but that's probably fine
     # mostly this will just remove those problematic directories hardcoded above.
+    included_paths = included_paths or []
     for entry in list(names):
         path = entry if type(entry) == str else entry.name
         if path in ignored_directories:
             safe_remove(names, entry)
-        if path.startswith(".") and IGNORE_HIDDEN_DIRECTORY_ENV:
+        if path.startswith(".") and IGNORE_HIDDEN_DIRECTORY_ENV and path not in included_paths:
             safe_remove(names, entry)
 
     # now apply the new logic
