@@ -9,12 +9,6 @@ class ApiServerAdmissionControlEventRateLimit(BaseK8Check):
         supported_kind = ['AdmissionConfiguration']
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
-    def get_resource_id(self, conf):
-        if "metadata" in conf:
-            if "name" in conf["metadata"]:
-                return 'AdmissionConfiguration.{}'.format(conf["metadata"]["name"])
-        return 'AdmissionConfiguration.spec.allowedCapabilities'
-
     def scan_spec_conf(self, conf):
         if "plugins" not in conf:
             return CheckResult.FAILED
