@@ -1,3 +1,4 @@
+import copy
 import io
 import logging
 import os
@@ -20,6 +21,8 @@ from checkov.common.graph.db_connectors.networkx.networkx_db_connector import Ne
 from checkov.common.graph.graph_builder.local_graph import LocalGraph
 from checkov.common.graph.graph_manager import GraphManager
 from checkov.kubernetes.graph_builder.local_graph import KubernetesLocalGraph
+import multiprocessing
+import platform
 
 
 class K8sKustomizeRunner(K8sRunner):
@@ -292,7 +295,8 @@ class Runner(BaseRunner):
             self.kustomizeProcessedFolderAndMeta[filePath]['overlay_name'] = checkovKustomizeEnvNameByPath
             logging.debug(f"Could not confirm base dir for Kustomize overlay/env. Using {checkovKustomizeEnvNameByPath} for Checkov Results.")
 
-    def _get_parsed_output(self, filePath, extractDir, output):
+    @staticmethod
+    def _get_parsed_output(filePath, extractDir, output, sharedKustomizeFileMappings):
         cur_source_file = None
         cur_writer = None
         last_line_dashes = False
@@ -316,7 +320,7 @@ class Runner(BaseRunner):
                 if source != cur_source_file:
                     if cur_writer:
                         # Here we are about to close a "complete" file. The function will validate it looks like a K8S manifest before continuing.
-                        self._curWriterValidateStoreMapAndClose(cur_writer, filePath)
+                        Runner._curWriterValidateStoreMapAndClose(cur_writer, filePath, sharedKustomizeFileMappings)
                     file_path = os.path.join(extractDir, str(source))
                     parent = os.path.dirname(file_path)
                     os.makedirs(parent, exist_ok=True)
@@ -333,65 +337,95 @@ class Runner(BaseRunner):
             line_num += 1
         return cur_writer
 
-    def _get_kubectl_output(self, filePath):
+    @staticmethod
+    def _get_kubectl_output(filePath, templateRendererCommand, kustomizeProcessedFolderAndMeta):
         # Template out the Kustomizations to Kubernetes YAML
-        if self.templateRendererCommand == "kubectl":
+        if templateRendererCommand == "kubectl":
             templateRenderCommandOptions = "kustomize"
-        if self.templateRendererCommand == "kustomize":
+        if templateRendererCommand == "kustomize":
             templateRenderCommandOptions = "build"
-        proc = subprocess.Popen([self.templateRendererCommand, templateRenderCommandOptions, filePath], stdout=subprocess.PIPE, stderr=subprocess.PIPE)  # nosec
+        proc = subprocess.Popen([templateRendererCommand, templateRenderCommandOptions, filePath], stdout=subprocess.PIPE, stderr=subprocess.PIPE)  # nosec
         output, _ = proc.communicate()
         logging.info(
-            f"Ran kubectl to build Kustomize output. DIR: {filePath}. TYPE: {self.kustomizeProcessedFolderAndMeta[filePath]['type']}.")
+            f"Ran kubectl to build Kustomize output. DIR: {filePath}. TYPE: {kustomizeProcessedFolderAndMeta[filePath]['type']}.")
         return output
 
-    def _get_env_or_base_path_prefix(self, filePath) -> str:
+    @staticmethod
+    def _get_env_or_base_path_prefix(filePath, kustomizeProcessedFolderAndMeta) -> str:
         env_or_base_path_prefix = None
-        if self.kustomizeProcessedFolderAndMeta[filePath]['type'] == "overlay":
-            if 'calculated_bases' not in self.kustomizeProcessedFolderAndMeta[filePath]:
+        if kustomizeProcessedFolderAndMeta[filePath]['type'] == "overlay":
+            if 'calculated_bases' not in kustomizeProcessedFolderAndMeta[filePath]:
                 logging.debug(f"Kustomize: Overlay with unknown base. User may have specified overlay dir directly. {filePath}")
                 env_or_base_path_prefix = ""
             else:
-                basePathParents = pathlib.Path(self.kustomizeProcessedFolderAndMeta[filePath]['calculated_bases']).parents
+                basePathParents = pathlib.Path(kustomizeProcessedFolderAndMeta[filePath]['calculated_bases']).parents
                 mostSignificantBasePath = "/" + basePathParents._parts[-3] + "/" + basePathParents._parts[-2] + "/" + basePathParents._parts[-1]
-                env_or_base_path_prefix = f"{mostSignificantBasePath}/{self.kustomizeProcessedFolderAndMeta[filePath]['overlay_name']}"
+                env_or_base_path_prefix = f"{mostSignificantBasePath}/{kustomizeProcessedFolderAndMeta[filePath]['overlay_name']}"
 
-        if self.kustomizeProcessedFolderAndMeta[filePath]['type'] == "base":
+        if kustomizeProcessedFolderAndMeta[filePath]['type'] == "base":
             # Validated base last three parents as a path
-            basePathParents = pathlib.Path(self.kustomizeProcessedFolderAndMeta[filePath]['filePath']).parents
+            basePathParents = pathlib.Path(kustomizeProcessedFolderAndMeta[filePath]['filePath']).parents
             mostSignificantBasePath = "/" + basePathParents._parts[-4] + "/" + basePathParents._parts[-3] + "/" + basePathParents._parts[-2]
             env_or_base_path_prefix = mostSignificantBasePath
 
         return env_or_base_path_prefix
 
+    @staticmethod
+    def _run_kustomize_parser(filePath, sharedKustomizeFileMappings, kustomizeProcessedFolderAndMeta, templateRendererCommand, target_folder_path):
+        logging.debug(f"Kustomization at {filePath} likley a {kustomizeProcessedFolderAndMeta[filePath]['type']}")
+        try:
+            output = Runner._get_kubectl_output(filePath, templateRendererCommand, kustomizeProcessedFolderAndMeta)
+        except Exception:
+            logging.warning(f"Error building Kustomize output at dir: {filePath}.", exc_info=True)
+            return
+
+        env_or_base_path_prefix = Runner._get_env_or_base_path_prefix(filePath, kustomizeProcessedFolderAndMeta)
+        if env_or_base_path_prefix is None:
+            logging.warning(f"env_or_base_path_prefix is None, filePath: {filePath}", exc_info=True)
+            return
+
+        extractDir = target_folder_path + env_or_base_path_prefix
+        os.makedirs(extractDir, exist_ok=True)
+
+        logging.debug(f"Kustomize: Temporary directory for {filePath} at {extractDir}")
+        output = str(output, 'utf-8')
+        cur_writer = Runner._get_parsed_output(filePath, extractDir, output, sharedKustomizeFileMappings)
+        if cur_writer:
+            Runner._curWriterValidateStoreMapAndClose(cur_writer, filePath, sharedKustomizeFileMappings)
+
     def run_kustomize_to_k8s(self, root_folder, files, runner_filter):
         kustomizeDirectories = self._findKustomizeDirectories(root_folder, files, runner_filter.excluded_paths)
         for kustomizedir in kustomizeDirectories:
             self.kustomizeProcessedFolderAndMeta[kustomizedir] = self._parseKustomization(kustomizedir)
         self.target_folder_path = tempfile.mkdtemp()
         for filePath in self.kustomizeProcessedFolderAndMeta:    
-            logging.debug(f"Kustomization at {filePath} likley a {self.kustomizeProcessedFolderAndMeta[filePath]['type']}")
             if self.kustomizeProcessedFolderAndMeta[filePath]['type'] == 'overlay':
                 self._handle_overlay_case(filePath)
-            try:
-                output = self._get_kubectl_output(filePath)
-            except Exception:
-                logging.warning(f"Error building Kustomize output at dir: {filePath}.", exc_info=True)
-                continue
+        
+        if platform.system() == 'Windows':
+            sharedKustomizeFileMappings = {}
+            for filePath in self.kustomizeProcessedFolderAndMeta:
+                Runner._run_kustomize_parser(filePath, sharedKustomizeFileMappings, self.kustomizeProcessedFolderAndMeta,
+                                             self.templateRendererCommand, self.target_folder_path)
+            self.kustomizeFileMappings = sharedKustomizeFileMappings
+            return
+        
+        manager = multiprocessing.Manager()
+        # make sure we have new dict
+        sharedKustomizeFileMappings = copy.copy(manager.dict())
+        sharedKustomizeFileMappings.clear()
+        jobs = []
+        for filePath in self.kustomizeProcessedFolderAndMeta:
+            p = multiprocessing.Process(target=Runner._run_kustomize_parser,
+                                        args=(filePath, sharedKustomizeFileMappings, self.kustomizeProcessedFolderAndMeta,
+                                            self.templateRendererCommand, self.target_folder_path))
+            jobs.append(p)
+            p.start()
 
-            env_or_base_path_prefix = self._get_env_or_base_path_prefix(filePath)
-            if env_or_base_path_prefix is None:
-                logging.warning(f"env_or_base_path_prefix is None, filePath: {filePath}", exc_info=True)
-                continue
+        for proc in jobs:
+            proc.join()
 
-            extractDir = self.target_folder_path + env_or_base_path_prefix
-            os.makedirs(extractDir, exist_ok=True)
-
-            logging.debug(f"Kustomize: Temporary directory for {filePath} at {extractDir}")
-            output = str(output, 'utf-8')
-            cur_writer = self._get_parsed_output(filePath, extractDir, output)
-            if cur_writer:
-                self._curWriterValidateStoreMapAndClose(cur_writer, filePath)
+        self.kustomizeFileMappings = dict(sharedKustomizeFileMappings)
 
     def run(self, root_folder, external_checks_dir=None, files=None, runner_filter=RunnerFilter(), collect_skip_comments=True):
         self.run_kustomize_to_k8s(root_folder, files, runner_filter)
@@ -419,7 +453,7 @@ class Runner(BaseRunner):
 
         return report
 
-    def _curWriterValidateStoreMapAndClose(self, cur_writer, FilePath):
+    def _curWriterValidateStoreMapAndClose(cur_writer, FilePath, sharedKustomizeFileMappings):
         currentFileName = cur_writer.name
         cur_writer.close()
         # Now we have a complete k8s manifest as we closed the writer, and it's temporary file name (currentFileName) plus the original file templated out (FilePath)
@@ -440,14 +474,12 @@ class Runner(BaseRunner):
                         itemName.append(currentYamlObject['metadata']['name'])
                     else:
                         itemName.append("noname")
-            
+
                     filename = f"{'-'.join(itemName)}.yaml"
                     newFullPathFilename = str(pathlib.Path(currentFileName).parent / filename) 
                     os.rename(currentFileName, newFullPathFilename) 
-                    self.kustomizeFileMappings[newFullPathFilename] = FilePath
-                
+                    sharedKustomizeFileMappings[newFullPathFilename] = FilePath
                 else:
                     raise Exception(f'Not a valid Kubernetes manifest (no apiVersion) while parsing Kustomize template: {FilePath}. Templated output: {currentFileName}.')
-
         except IsADirectoryError:
             pass
