@@ -1,3 +1,4 @@
+import datetime
 import linecache
 import logging
 import os
@@ -8,17 +9,18 @@ from detect_secrets import SecretsCollection
 from detect_secrets.core import scan
 from detect_secrets.core.potential_secret import PotentialSecret
 from detect_secrets.settings import transient_settings
-from typing_extensions import TypedDict
 
-from checkov.common.bridgecrew.platform_integration import bc_integration
+from checkov.common.bridgecrew.integration_features.features.policy_metadata_integration import integration as metadata_integration
+from checkov.common.bridgecrew.severities import Severity
 from checkov.common.comment.enum import COMMENT_REGEX
 from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.models.consts import SUPPORTED_FILE_EXTENSIONS
 from checkov.common.models.enums import CheckResult
 from checkov.common.output.record import Record
-from checkov.common.output.report import Report
+from checkov.common.output.report import Report, CheckType
 from checkov.common.runners.base_runner import BaseRunner, filter_ignored_paths
 from checkov.common.runners.base_runner import ignored_directories
+from checkov.common.typing import _CheckResult
 from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR
 from checkov.runner_filter import RunnerFilter
 
@@ -47,15 +49,11 @@ CHECK_ID_TO_SECRET_TYPE = {v: k for k, v in SECRET_TYPE_TO_ID.items()}
 
 ENTROPY_KEYWORD_LIMIT = 3
 PROHIBITED_FILES = ['Pipfile.lock', 'yarn.lock', 'package-lock.json', 'requirements.txt']
-
-
-class _CheckResult(TypedDict, total=False):
-    result: CheckResult
-    suppress_comment: str
+MAX_FILE_SIZE = int(os.getenv('CHECKOV_MAX_FILE_SIZE', '5000000'))  # 5 MB is default limit
 
 
 class Runner(BaseRunner):
-    check_type = 'secrets'
+    check_type = CheckType.SECRETS
 
     def run(
         self,
@@ -135,10 +133,11 @@ class Runner(BaseRunner):
 
             for _, secret in iter(secrets):
                 check_id = SECRET_TYPE_TO_ID.get(secret.type)
-                bc_check_id = bc_integration.ckv_to_bc_id_mapping.get(check_id) if bc_integration.ckv_to_bc_id_mapping else None
                 if not check_id:
                     continue
-                if runner_filter.checks and not runner_filter.should_run_check(check_id, bc_check_id):
+                bc_check_id = metadata_integration.get_bc_id(check_id)
+                severity = metadata_integration.get_severity(check_id)
+                if runner_filter.checks and not runner_filter.should_run_check(check_id=check_id, bc_check_id=bc_check_id, severity=severity):
                     continue
                 result: _CheckResult = {'result': CheckResult.FAILED}
                 line_text = linecache.getline(secret.filename, secret.line_number)
@@ -147,6 +146,7 @@ class Runner(BaseRunner):
                 result = self.search_for_suppression(
                     check_id=check_id,
                     bc_check_id=bc_check_id,
+                    severity=severity,
                     secret=secret,
                     runner_filter=runner_filter,
                 ) or result
@@ -154,6 +154,7 @@ class Runner(BaseRunner):
                 report.add_record(Record(
                     check_id=check_id,
                     bc_check_id=bc_check_id,
+                    severity=severity,
                     check_name=secret.type,
                     check_result=result,
                     code_block=[(secret.line_number, line_text)],
@@ -162,7 +163,7 @@ class Runner(BaseRunner):
                     resource=secret.secret_hash,
                     check_class=None,
                     evaluations=None,
-                    file_abs_path=os.path.abspath(secret.filename)
+                    file_abs_path=os.path.abspath(secret.filename),
                 ))
 
             return report
@@ -171,14 +172,29 @@ class Runner(BaseRunner):
     def _scan_files(files_to_scan, secrets):
         # implemented the scan function like secrets.scan_files
         def _safe_scan(f):
+            full_file_path = os.path.join(secrets.root, f)
+            file_size = os.path.getsize(full_file_path)
+            if file_size > MAX_FILE_SIZE > 0:
+                logging.info(f'Skipping secret scanning on {full_file_path} due to file size. To scan this file for '
+                             f'secrets, run this command again with the environment variable "CHECKOV_MAX_FILE_SIZE" '
+                             f'to 0 or {file_size + 1}')
+                return list()
             try:
-                return list(scan.scan_file(os.path.join(secrets.root, f)))
-            except Exception as err:
-                logging.warning(f"Secret scanning:could not process file {f}, {err}")
+                start_time = datetime.datetime.now()
+                file_results = list(scan.scan_file(full_file_path))
+                end_time = datetime.datetime.now()
+                run_time = end_time - start_time
+                if run_time > datetime.timedelta(seconds=10):
+                    logging.info(f'Secret scanning for {full_file_path} took {run_time} seconds')
+                return file_results
+            except Exception:
+                logging.warning(f"Secret scanning:could not process file {f}")
+                logging.debug("Complete trace:", exc_info=True)
                 return list()
 
         results = parallel_runner.run_function(
-            lambda f: list(_safe_scan(f)), files_to_scan)
+            func=lambda f: list(_safe_scan(f)), items=files_to_scan,
+            run_multiprocess=os.getenv("RUN_SECRETS_MULTIPROCESS", "").lower() == "true")
         for secrets_results in results:
             for secret in secrets_results:
                 secrets[os.path.relpath(secret.filename, secrets.root)].add(secret)
@@ -187,10 +203,11 @@ class Runner(BaseRunner):
     def search_for_suppression(
         check_id: str,
         bc_check_id: str,
+        severity: Severity,
         secret: PotentialSecret,
         runner_filter: RunnerFilter
     ) -> Optional[_CheckResult]:
-        if not runner_filter.should_run_check(check_id, bc_check_id) and check_id in CHECK_ID_TO_SECRET_TYPE.keys():
+        if not runner_filter.should_run_check(check_id=check_id, bc_check_id=bc_check_id, severity=severity) and check_id in CHECK_ID_TO_SECRET_TYPE.keys():
             return {
                 "result": CheckResult.SKIPPED,
                 "suppress_comment": f"Secret scan {check_id} is skipped"
