@@ -12,6 +12,8 @@ from yaml import YAMLError
 
 from checkov.cloudformation.parser import cfn_yaml
 from checkov.cloudformation.context_parser import ContextParser
+from checkov.cloudformation.parser.cfn_yaml import CfnParseError
+from checkov.common.models.consts import SLS_DEFAULT_VAR_PATTERN
 from checkov.common.parsers.node import DictNode, StrNode
 
 logger = logging.getLogger(__name__)
@@ -25,7 +27,6 @@ STACK_TAGS_TOKEN = 'stackTags'  # nosec
 TAGS_TOKEN = 'tags'  # nosec
 SUPPORTED_PROVIDERS = ['aws']
 
-DEFAULT_VAR_PATTERN = re.compile(r"\${([^{}]+?)}")
 QUOTED_WORD_SYNTAX = re.compile(r"(?:('|\").*?\1)")
 FILE_LOCATION_PATTERN = re.compile(r'^file\(([^?%*:|"<>]+?)\)')
 
@@ -52,8 +53,11 @@ def parse(filename):
     except UnicodeDecodeError:
         logger.error('Cannot read file contents: %s', filename)
         return
-    except YAMLError as e:
-        print(e)
+    except CfnParseError:
+        logger.warning(f"Failed to parse file {filename} because it isn't a valid template")
+        return
+    except YAMLError:
+        logger.warning(f"Failed to parse file {filename} as a yaml")
         return
 
     process_variables(template, filename)
@@ -101,7 +105,7 @@ Modifies the template data in-place to resolve variables.
         # Remove to prevent self-matching during processing
         del template["provider"]["variableSyntax"]
     else:
-        var_pattern = DEFAULT_VAR_PATTERN
+        var_pattern = SLS_DEFAULT_VAR_PATTERN
     compiled_var_pattern = re.compile(var_pattern)
 
     # Processing is done in a loop to deal with chained references and the like.
