@@ -1,13 +1,12 @@
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
-from checkov.common.util.type_forcers import force_int
 
 
 class ElasticsearchNodeToNodeEncryption(BaseResourceCheck):
     def __init__(self):
         name = "Ensure all Elasticsearch has node-to-node encryption enabled"
         id = "CKV_AWS_6"
-        supported_resources = ['aws_elasticsearch_domain']
+        supported_resources = ['aws_elasticsearch_domain', 'aws_opensearch_domain']
         categories = [CheckCategories.ENCRYPTION]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
@@ -15,6 +14,7 @@ class ElasticsearchNodeToNodeEncryption(BaseResourceCheck):
         """
             Looks for node to node encryption configuration at aws_elasticsearch_domain:
             https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html
+            and https://registry.terraform.io/providers/hashicorp/aws/latest/docs/resources/opensearch_domain
         :param conf: aws_elasticsearch_domain configuration
         :return: <CheckResult>
         """
