@@ -1,7 +1,8 @@
 import logging
 from typing import Dict
 
-from checkov.common.parsers.json import parse as json_parse
+from checkov.cloudformation.parser.cfn_yaml import ContentType
+from checkov.cloudformation.parser import cfn_yaml
 from checkov.common.parsers.node import DictNode
 
 LOGGER = logging.getLogger(__name__)
@@ -11,7 +12,11 @@ def parse(filename, out_parsing_errors: Dict[str, str]):
     """
         Decode filename into an object
     """
-    (template, template_lines) = json_parse(filename, out_parsing_errors=out_parsing_errors)
+    try:
+        (template, template_lines) = cfn_yaml.load(filename, ContentType.TFPLAN)
+    except Exception as e:
+        out_parsing_errors[filename] = str(e)
+        return None, None
 
     if (
         template is not None
