@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import json
 import logging
 import os
@@ -11,7 +13,7 @@ import deep_merge
 import hcl2
 from lark import Tree
 
-from checkov.common.runners.base_runner import filter_ignored_paths
+from checkov.common.runners.base_runner import filter_ignored_paths, IGNORE_HIDDEN_DIRECTORY_ENV
 from checkov.common.util.config_utils import should_scan_hcl_files
 from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR, RESOLVED_MODULE_ENTRY_NAME
 from checkov.common.util.json_utils import CustomJSONEncoder
@@ -66,6 +68,7 @@ class Parser:
         self.module_address_map = {}
         self.tf_var_files = tf_var_files
         self.scan_hcl = should_scan_hcl_files()
+        self.dirname_cache = {}
 
         if self.out_evaluations_context is None:
             self.out_evaluations_context = {}
@@ -101,15 +104,17 @@ class Parser:
         load_tf_modules(directory)
         self._parse_directory(dir_filter=lambda d: self._check_process_dir(d), vars_files=vars_files)
 
-    def parse_file(self, file: str, parsing_errors: Dict[str, Exception] = None, scan_hcl = False) -> Optional[Dict]:
+    def parse_file(
+        self, file: str, parsing_errors: Optional[Dict[str, Exception]] = None, scan_hcl: bool = False
+    ) -> Optional[Dict[str, Any]]:
         if file.endswith(".tf") or file.endswith(".tf.json") or (scan_hcl and file.endswith(".hcl")):
             parse_result = _load_or_die_quietly(Path(file), parsing_errors)
             if parse_result:
                 parse_result = self._serialize_definitions(parse_result)
                 parse_result = self._clean_parser_types(parse_result)
                 return parse_result
-        else:
-            return None
+
+        return None
 
     def _parse_directory(self, include_sub_dirs: bool = True,
                          module_loader_registry: ModuleLoaderRegistry = default_ml_registry,
@@ -190,14 +195,14 @@ class Parser:
         explicit_var_files: List[os.DirEntry] = []  # files passed with --var-file; only process the ones that are in this directory
 
         dir_contents = list(os.scandir(directory))
-        if excluded_paths:
+        if excluded_paths or IGNORE_HIDDEN_DIRECTORY_ENV:
             filter_ignored_paths(root_dir, dir_contents, excluded_paths)
 
         tf_files_to_load = []
         for file in dir_contents:
             # Ignore directories and hidden files
             try:
-                if not file.is_file() or file.name.startswith("."):
+                if not file.is_file():
                     continue
             except OSError:
                 # Skip files that can't be accessed
@@ -317,7 +322,7 @@ class Parser:
             result = _load_or_die_quietly(file, parsing_errors)
             # the exceptions type can un-pickleable
             for path, e in parsing_errors.items():
-                parsing_errors[path] = Exception(str(e))
+                parsing_errors[path] = e
 
             return (file.path, result), parsing_errors
 
@@ -356,7 +361,7 @@ class Parser:
             # Don't process a file in a directory other than the directory we're processing. For example,
             # if we're down dealing with <top_dir>/<module>/something.tf, we don't want to rescan files
             # up in <top_dir>.
-            if os.path.dirname(file) != root_dir:
+            if self.get_dirname(file) != root_dir:
                 continue
             # Don't process a file reference which has already been processed
             if file.endswith("]"):
@@ -427,7 +432,7 @@ class Parser:
 
                         module_definitions = {path: self.out_definitions[path] for path in
                                               list(self.out_definitions.keys()) if
-                                              os.path.dirname(path) == content.path()}
+                                              self.get_dirname(path) == content.path()}
 
                         if not module_definitions:
                             continue
@@ -489,12 +494,13 @@ class Parser:
         source: str,
         download_external_modules: bool = False,
         external_modules_download_path: str = DEFAULT_EXTERNAL_MODULES_DIR,
-        parsing_errors: Optional[Dict[str, Exception]] = None,
-        excluded_paths: Optional[List[str]] = None,
-        vars_files: Optional[List[str]] = None,
-        external_modules_content_cache: Optional[Dict[str, ModuleContent]] = None
-    ) -> Tuple[Module, Dict[str, Dict[str, Any]]]:
-        tf_definitions: Dict[str, Dict[str, Any]] = {}
+        parsing_errors: dict[str, Exception] | None = None,
+        excluded_paths: list[str] | None = None,
+        vars_files: list[str] | None = None,
+        external_modules_content_cache: dict[str, ModuleContent] | None = None,
+        create_graph: bool = True,
+    ) -> tuple[Module | None, dict[str, dict[str, Any]]]:
+        tf_definitions: dict[str, dict[str, Any]] = {}
         self.parse_directory(directory=source_dir, out_definitions=tf_definitions, out_evaluations_context={},
                              out_parsing_errors=parsing_errors if parsing_errors is not None else {},
                              download_external_modules=download_external_modules,
@@ -503,7 +509,10 @@ class Parser:
         tf_definitions = self._clean_parser_types(tf_definitions)
         tf_definitions = self._serialize_definitions(tf_definitions)
 
-        module, tf_definitions = self.parse_hcl_module_from_tf_definitions(tf_definitions, source_dir, source)
+        module = None
+        if create_graph:
+            module, tf_definitions = self.parse_hcl_module_from_tf_definitions(tf_definitions, source_dir, source)
+
         return module, tf_definitions
 
     def parse_hcl_module_from_tf_definitions(
@@ -689,6 +698,13 @@ class Parser:
                 block = {var_name: {"default": default}}
                 module.add_blocks(BlockType.TF_VARIABLE, block, path, source)
 
+    def get_dirname(self, path: str) -> str:
+        dirname_path = self.dirname_cache.get(path)
+        if not dirname_path:
+            dirname_path = os.path.dirname(path)
+            self.dirname_cache[path] = dirname_path
+        return dirname_path
+
 
 def _load_or_die_quietly(file: os.PathLike, parsing_errors: Dict,
                          clean_definitions: bool = True) -> Optional[Mapping]:
@@ -714,7 +730,7 @@ Load JSON or HCL, depending on filename.
                 else:
                     return non_malformed_definitions
     except Exception as e:
-        logging.debug(f'failed while parsing file {file_path}', exc_info=e)
+        logging.debug(f'failed while parsing file {file_path}', exc_info=True)
         parsing_errors[file_path] = e
         return None
 
@@ -743,7 +759,7 @@ def validate_malformed_definitions(raw_data):
 
 def clean_bad_definitions(tf_definition_list):
     return {
-        block_type: list(filter(lambda definition_list: block_type == 'locals' or
+        block_type: list(filter(lambda definition_list: block_type in [BlockType.LOCALS, BlockType.TERRAFORM] or
                                                         not isinstance(definition_list, dict)
                                                         or len(definition_list.keys()) == 1,
                                 tf_definition_list[block_type]))
@@ -772,9 +788,8 @@ def _remove_module_dependency_in_path(path):
 def _safe_index(sequence_hopefully, index) -> Optional[Any]:
     try:
         return sequence_hopefully[index]
-    except IndexError as e:
-        logging.debug(f'Failed to parse index int ({index}) out of {sequence_hopefully}')
-        logging.debug(e, stack_info=True)
+    except IndexError:
+        logging.debug(f'Failed to parse index int ({index}) out of {sequence_hopefully}', exc_info=True)
         return None
 
 
