@@ -2,7 +2,7 @@ import copy
 import dataclasses
 import logging
 import os
-from typing import Dict, Optional, Tuple, List, Type
+from typing import Dict, Optional, Tuple, List, Type, Any, Set
 
 import dpath.util
 
@@ -10,13 +10,12 @@ from checkov.common.checks_infra.registry import get_graph_checks_registry
 from checkov.common.graph.checks_infra.registry import BaseRegistry
 from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
 from checkov.common.graph.graph_builder.local_graph import LocalGraph
-from checkov.common.graph.graph_manager import GraphManager
 from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.models.enums import CheckResult
 from checkov.common.output.graph_record import GraphRecord
 from checkov.common.output.record import Record
-from checkov.common.output.report import Report, merge_reports, remove_duplicate_results
-from checkov.common.runners.base_runner import BaseRunner
+from checkov.common.output.report import Report, merge_reports, remove_duplicate_results, CheckType
+from checkov.common.runners.base_runner import BaseRunner, CHECKOV_CREATE_GRAPH
 from checkov.common.util import data_structures_utils
 from checkov.common.util.config_utils import should_scan_hcl_files
 from checkov.common.variables.context import EvaluationContext
@@ -27,7 +26,7 @@ from checkov.terraform.checks.provider.registry import provider_registry
 from checkov.terraform.checks.resource.registry import resource_registry
 from checkov.terraform.context_parsers.registry import parser_registry
 from checkov.terraform.evaluation.base_variable_evaluation import BaseVariableEvaluation
-from checkov.terraform.graph_builder.graph_components.attribute_names import CustomAttributes
+from checkov.common.graph.graph_builder.graph_components.attribute_names import CustomAttributes
 from checkov.terraform.graph_builder.graph_components.block_types import BlockType
 from checkov.terraform.graph_builder.graph_to_tf_definitions import convert_graph_vertices_to_tf_definitions
 from checkov.terraform.graph_builder.local_graph import TerraformLocalGraph
@@ -36,13 +35,14 @@ from checkov.terraform.graph_manager import TerraformGraphManager
 from checkov.terraform.parser import Parser
 from checkov.terraform.tag_providers import get_resource_tags
 
+
 dpath.options.ALLOW_EMPTY_STRING_KEYS = True
 
 CHECK_BLOCK_TYPES = frozenset(['resource', 'data', 'provider', 'module'])
 
 
 class Runner(BaseRunner):
-    check_type = "terraform"
+    check_type = CheckType.TERRAFORM
 
     def __init__(
         self,
@@ -51,8 +51,9 @@ class Runner(BaseRunner):
         external_registries: Optional[List[BaseRegistry]] = None,
         source: str = "Terraform",
         graph_class: Type[LocalGraph] = TerraformLocalGraph,
-        graph_manager: Optional[GraphManager] = None
+        graph_manager: Optional[TerraformGraphManager] = None
     ) -> None:
+        super().__init__(file_extensions=['.tf', '.hcl'])
         self.external_registries = [] if external_registries is None else external_registries
         self.graph_class = graph_class
         self.parser = parser
@@ -60,9 +61,12 @@ class Runner(BaseRunner):
         self.context = None
         self.breadcrumbs = None
         self.evaluations_context: Dict[str, Dict[str, EvaluationContext]] = {}
-        self.graph_manager = graph_manager if graph_manager is not None else TerraformGraphManager(source=source,
+        self.graph_manager: TerraformGraphManager = graph_manager if graph_manager is not None else TerraformGraphManager(source=source,
                                                                                                    db_connector=db_connector)
         self.graph_registry = get_graph_checks_registry(self.check_type)
+        self.definitions_with_modules: Dict[str, Dict] = {}
+        self.referrer_cache: Dict[str, str] = {}
+        self.non_referred_cache: Set[str] = set()
 
     block_type_registries = {
         'resource': resource_registry,
@@ -83,6 +87,7 @@ class Runner(BaseRunner):
         parsing_errors = {}
         self.load_external_checks(external_checks_dir)
         scan_hcl = should_scan_hcl_files()
+        local_graph = None
 
         if self.context is None or self.definitions is None or self.breadcrumbs is None:
             self.definitions = {}
@@ -90,29 +95,33 @@ class Runner(BaseRunner):
             if root_folder:
                 root_folder = os.path.abspath(root_folder)
 
-                local_graph, tf_definitions = self.graph_manager.build_graph_from_source_directory(
+                local_graph, self.definitions = self.graph_manager.build_graph_from_source_directory(
                     source_dir=root_folder,
                     local_graph_class=self.graph_class,
                     download_external_modules=runner_filter.download_external_modules,
                     external_modules_download_path=runner_filter.external_modules_download_path,
                     parsing_errors=parsing_errors,
                     excluded_paths=runner_filter.excluded_paths,
-                    vars_files=runner_filter.var_files
+                    vars_files=runner_filter.var_files,
+                    create_graph=CHECKOV_CREATE_GRAPH,
                 )
             elif files:
                 files = [os.path.abspath(file) for file in files]
                 root_folder = os.path.split(os.path.commonprefix(files))[0]
                 self.parser.evaluate_variables = False
                 self._parse_files(files, scan_hcl, parsing_errors)
-                local_graph = self.graph_manager.build_graph_from_definitions(self.definitions)
+
+                if CHECKOV_CREATE_GRAPH:
+                    local_graph = self.graph_manager.build_graph_from_definitions(self.definitions)
             else:
                 raise Exception("Root directory was not specified, files were not specified")
 
-            for vertex in local_graph.vertices:
-                if vertex.block_type == BlockType.RESOURCE:
-                    report.add_resource(f'{vertex.path}:{vertex.id}')
-            self.graph_manager.save_graph(local_graph)
-            self.definitions, self.breadcrumbs = convert_graph_vertices_to_tf_definitions(local_graph.vertices, root_folder)
+            if CHECKOV_CREATE_GRAPH and local_graph:
+                for vertex in local_graph.vertices:
+                    if vertex.block_type == BlockType.RESOURCE:
+                        report.add_resource(f'{vertex.path}:{vertex.id}')
+                self.graph_manager.save_graph(local_graph)
+                self.definitions, self.breadcrumbs = convert_graph_vertices_to_tf_definitions(local_graph.vertices, root_folder)
         else:
             logging.info("Scanning root folder using existing tf_definitions")
 
@@ -120,8 +129,10 @@ class Runner(BaseRunner):
 
         report.add_parsing_errors(list(parsing_errors.keys()))
 
-        graph_report = self.get_graph_checks_report(root_folder, runner_filter)
-        merge_reports(report, graph_report)
+        if CHECKOV_CREATE_GRAPH:
+            graph_report = self.get_graph_checks_report(root_folder, runner_filter)
+            merge_reports(report, graph_report)
+
         report = remove_duplicate_results(report)
 
         return report
@@ -132,6 +143,26 @@ class Runner(BaseRunner):
                 resource_registry.load_external_checks(directory)
                 self.graph_registry.load_external_checks(directory)
 
+    def get_connected_node(self, entity, root_folder) -> Optional[Dict[str, Any]]:
+        connected_entity = entity.get('connected_node')
+        if not connected_entity:
+            return None
+        connected_entity_context, connected_entity_evaluations = self.get_entity_context_and_evaluations(connected_entity)
+        if not connected_entity_context:
+            return None
+        full_file_path = connected_entity[CustomAttributes.FILE_PATH]
+        connected_node_data = {}
+        connected_node_data['code_block'] = connected_entity_context.get('code_lines')
+        connected_node_data['file_path'] = f"/{os.path.relpath(full_file_path, root_folder)}"
+        connected_node_data['file_line_range'] = [connected_entity_context.get('start_line'),
+                                                  connected_entity_context.get('end_line')]
+        connected_node_data['resource'] = ".".join(connected_entity_context['definition_path'])
+        connected_node_data['entity_tags'] = connected_entity.get('tags', {})
+        connected_node_data['evaluations'] = connected_entity_evaluations
+        connected_node_data['file_abs_path'] = os.path.abspath(full_file_path)
+        connected_node_data['resource_address'] = connected_entity_context.get('address')
+        return connected_node_data
+
     def get_graph_checks_report(self, root_folder, runner_filter: RunnerFilter):
         report = Report(self.check_type)
         checks_results = self.run_graph_checks_results(runner_filter)
@@ -149,6 +180,7 @@ class Runner(BaseRunner):
                             copy_of_check_result['suppress_comment'] = skipped_check['suppress_comment']
                             break
                     copy_of_check_result['entity'] = entity.get(CustomAttributes.CONFIG)
+                    connected_node_data = self.get_connected_node(entity, root_folder)
                     record = Record(
                         check_id=check.id,
                         bc_check_id=check.bc_id,
@@ -163,7 +195,11 @@ class Runner(BaseRunner):
                         evaluations=entity_evaluations,
                         check_class=check.__class__.__module__,
                         file_abs_path=os.path.abspath(full_file_path),
-                        resource_address=entity_context.get('address')
+                        resource_address=entity_context.get('address'),
+                        severity=check.severity,
+                        bc_category=check.bc_category,
+                        benchmarks=check.benchmarks,
+                        connected_node=connected_node_data
                     )
                     if self.breadcrumbs:
                         breadcrumb = self.breadcrumbs.get(record.file_path, {}).get(record.resource)
@@ -243,8 +279,8 @@ class Runner(BaseRunner):
             caller_file_line_range = None
 
             if module_referrer is not None:
-                referrer_id = self._find_id_for_referrer(full_file_path,
-                                                         self.definitions)
+                referrer_id = self._find_id_for_referrer(full_file_path)
+
                 if referrer_id:
                     entity_id = f"{referrer_id}.{entity_id}"        # ex: module.my_module.aws_s3_bucket.my_bucket
                     abs_caller_file = module_referrer[:module_referrer.rindex("#")]
@@ -297,17 +333,31 @@ class Runner(BaseRunner):
             (entity_type, entity_name, entity_config) = registry.extract_entity_details(entity)
             tags = get_resource_tags(entity_type, entity_config)
             for check, check_result in results.items():
-                record = Record(check_id=check.id, bc_check_id=check.bc_id, check_name=check.name, check_result=check_result,
-                                code_block=entity_code_lines, file_path=scanned_file,
-                                file_line_range=entity_lines_range,
-                                resource=entity_id, evaluations=entity_evaluations,
-                                check_class=check.__class__.__module__, file_abs_path=absolut_scanned_file_path,
-                                entity_tags=tags,
-                                caller_file_path=caller_file_path,
-                                caller_file_line_range=caller_file_line_range)
-                breadcrumb = self.breadcrumbs.get(record.file_path, {}).get('.'.join([entity_type, entity_name]))
-                if breadcrumb:
-                    record = GraphRecord(record, breadcrumb)
+                record = Record(
+                    check_id=check.id,
+                    bc_check_id=check.bc_id,
+                    check_name=check.name,
+                    check_result=check_result,
+                    code_block=entity_code_lines,
+                    file_path=scanned_file,
+                    file_line_range=entity_lines_range,
+                    resource=entity_id,
+                    evaluations=entity_evaluations,
+                    check_class=check.__class__.__module__,
+                    file_abs_path=absolut_scanned_file_path,
+                    entity_tags=tags,
+                    caller_file_path=caller_file_path,
+                    caller_file_line_range=caller_file_line_range,
+                    severity=check.severity,
+                    bc_category=check.bc_category,
+                    benchmarks=check.benchmarks
+                )
+
+                if CHECKOV_CREATE_GRAPH:
+                    breadcrumb = self.breadcrumbs.get(record.file_path, {}).get('.'.join([entity_type, entity_name]))
+                    if breadcrumb:
+                        record = GraphRecord(record, breadcrumb)
+
                 record.set_guideline(check.guideline)
                 report.add_record(record=record)
 
@@ -319,7 +369,7 @@ class Runner(BaseRunner):
             parse_result = self.parser.parse_file(file=file, parsing_errors=file_parsing_errors, scan_hcl=scan_hcl)
             # the exceptions type can un-pickleable so we need to cast them to Exception
             for path, e in file_parsing_errors.items():
-                file_parsing_errors[path] = Exception(str(e))
+                file_parsing_errors[path] = Exception(e.__repr__())
             return file, parse_result, file_parsing_errors
 
         results = parallel_runner.run_function(parse_file, files)
@@ -378,17 +428,37 @@ class Runner(BaseRunner):
         else:
             return file_path, None
 
-    @staticmethod
-    def _find_id_for_referrer(full_file_path, definitions) -> Optional[str]:
-        for file, file_content in definitions.items():
-            if "module" not in file_content:
-                continue
+    def _find_id_for_referrer(self, full_file_path) -> Optional[str]:
+        cached_referrer = self.referrer_cache.get(full_file_path)
+        if cached_referrer:
+            return cached_referrer
+        if full_file_path in self.non_referred_cache:
+            return None
 
+        if not self.definitions_with_modules:
+            self._prepare_definitions_with_modules()
+        for file, file_content in self.definitions_with_modules.items():
             for modules in file_content["module"]:
                 for module_name, module_content in modules.items():
                     if "__resolved__" not in module_content:
                         continue
 
                     if full_file_path in module_content["__resolved__"]:
-                        return f"module.{module_name}"
+                        id_referrer = f"module.{module_name}"
+                        self.referrer_cache[full_file_path] = id_referrer
+                        return id_referrer
+
+        self.non_referred_cache.add(full_file_path)
         return None
+
+    def _prepare_definitions_with_modules(self):
+        def __cache_file_content(file_modules: list):
+            for modules in file_modules:
+                for module_content in modules.values():
+                    if "__resolved__" in module_content:
+                        self.definitions_with_modules[file] = file_content
+                        return
+
+        for file, file_content in self.definitions.items():
+            if "module" in file_content:
+                __cache_file_content(file_modules=file_content["module"])
